# circuitikz
- https://github.com/circuitikz/circuitikz
- License: GPL
- circuitikz's macros are used in some of the LaTeX source generated by _pyimpspec_.

# cvxopt
- https://github.com/cvxopt/cvxopt
- License: GPLv3 or later
- Dependency.

# cvxpy
- https://github.com/cvxpy/cvxpy
- License: Apache License version 2.0
- Optional dependency.

# DRT-python-code
- https://github.com/akulikovsky/DRT-python-code
- License: GPLv3 or later
- Copied/ported code to implement calculation of the distribution of relaxation times (DRT) using Tikhonov regularization and non-negative least squares fitting.

# Elchemea Analytical
- https://www.elchemea.com/
- License: GPLv3 or later
- Copied/ported code to implement some circuit elements.

# impedance.py
- https://github.com/ECSHackWeek/impedance.py
- License: MIT
- Copied code to implement linear Kramers-Kronig tests using matrix solvers.

# lmfit
- https://github.com/lmfit/lmfit-py
- License: BSD 3-clause
- Dependency.

# matplotlib
- https://github.com/matplotlib/matplotlib
- License: custom license
- Dependency.

# numpy
- https://github.com/numpy/numpy
- License: BSD 3-clause
- Dependency.

# odfpy
- https://github.com/eea/odfpy
- License: GPLv2 or later
- Dependency via _pandas_.

# openpyxl
- https://foss.heptapod.net/openpyxl/openpyxl
- License: MIT
- Dependency via _pandas_.

# pandas
- https://github.com/pandas-dev/pandas
- License: BSD 3-clause
- Dependency.

# pyDRTtools
- https://github.com/ciuccislab/pyDRTtools
- License: MIT
- Copied/ported code to implement calculation of the distribution of relaxation times (DRT) using Tikhonov regularization combined with either piecewise linear discretization or radial basis function (RBF) discretization, and scoring of EIS data using the Bayesian Hilbert transform (BHT) method.

# SchemDraw
- https://bitbucket.org/cdelker/schemdraw/
- License: MIT
- Dependency.

# SciPy
- https://github.com/scipy/scipy
- License: BSD 3-clause
- Dependency.

# SymPy
- https://github.com/sympy/sympy
- License: BSD 3-clause
- Dependency.

# tabulate
- https://github.com/astanin/python-tabulate
- License: MIT
- Dependency via _pandas_.

# tol_colors
- https://personal.sron.nl/~pault/data/tol_colors.py
- License: BSD 3-clause
- Copied values for some colors.
